@@ -1,3 +1,4 @@
+"""adadmire: Anomaly detection in mixed high-dimensional molecular data."""
 from adadmire.main import (
     get_threshold_continuous,
     get_threshold_discrete,
@@ -5,5 +6,7 @@ from adadmire.main import (
     pred_continuous,
     pred_discrete,
     place_anomalies_continuous,
-    impute
+    impute,
+    penalty,
+    admire
 )
